==> surfacetopography-1.15.0.tar.gz: surfacetopography-1.15.0/test/IO/test_nmm.py <==
#
# Copyright 2024 Lars Pastewka
#
# ### MIT license
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

import os

import numpy as np
import pytest
from NuMPI import MPI

from SurfaceTopography.IO.NMM import NMMReader

pytestmark = pytest.mark.skipif(
    MPI.COMM_WORLD.Get_size() > 1,
    reason="tests only serial functionalities, please execute with pytest",
)


def test_nmm_metadata(file_format_examples, plot=False):
    file_path = os.path.join(file_format_examples, "nmm-1.zip")

    r = NMMReader(file_path)
    t = r.topography()

    assert t.nb_grid_pts == (20001,)
    print(t.physical_sizes)
    np.testing.assert_allclose(t.physical_sizes, 0.0007071105772375498)
    np.testing.assert_allclose(t.rms_height_from_profile(), 1.135232e-06, rtol=1e-6)

    if plot:
        import matplotlib.pyplot as plt

        plt.plot(*t.positions_and_heights(), "k-")
        plt.show()

==> surfacetopography-1.18.1.tar.gz: surfacetopography-1.18.1/test/IO/test_nmm.py <==
#
# Copyright 2024 Lars Pastewka
#
# ### MIT license
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

import os

import numpy as np
import pytest
from NuMPI import MPI

from SurfaceTopography.IO.NMM import NMMReader

pytestmark = pytest.mark.skipif(
    MPI.COMM_WORLD.Get_size() > 1,
    reason="tests only serial functionalities, please execute with pytest",
)


def test_nmm_metadata(file_format_examples, plot=False):
    file_path = os.path.join(file_format_examples, "nmm-1.zip")

    r = NMMReader(file_path)
    t = r.topography()

    assert t.nb_grid_pts == (20001, 10)
    assert t.unit == "µm"
    np.testing.assert_allclose(t.physical_sizes, (1000, 9))
    np.testing.assert_allclose(t.rms_height_from_profile(), 1.222713, rtol=1e-6)

    if plot:
        import matplotlib.pyplot as plt

        t.plot()
        plt.show()
